diff --git a/src/yuzu/configuration/configure_graphics.ui b/src/yuzu/configuration/configure_graphics.ui
index 94eba6c7e6..39f70e406f 100644
--- a/src/yuzu/configuration/configure_graphics.ui
+++ b/src/yuzu/configuration/configure_graphics.ui
@@ -206,14 +206,14 @@
            <item>
             <widget class="QLabel" name="vsync_mode_label">
              <property name="text">
-              <string>V-Sync Mode:</string>
+              <string>VSync Mode:</string>
              </property>
             </widget>
            </item>
            <item>
             <widget class="QComboBox" name="vsync_mode_combobox">
              <property name="toolTip">
-              <string>FIFO (V-Sync) does not drop frames or exhibit tearing but is limited by the screen refresh rate.
+              <string>FIFO (VSync) does not drop frames or exhibit tearing but is limited by the screen refresh rate.
 FIFO Relaxed is similar to FIFO but allows tearing as it recovers from a slow down.
 Mailbox can have lower latency than FIFO and does not tear but may drop frames.
 Immediate (no synchronization) just presents whatever is available and can exhibit tearing.</string>
diff --git a/src/yuzu/configuration/configure_graphics.cpp b/src/yuzu/configuration/configure_graphics.cpp
index 4a4a7bb0b0..6f5bc8d90b 100644
--- a/src/yuzu/configuration/configure_graphics.cpp
+++ b/src/yuzu/configuration/configure_graphics.cpp
@@ -272,7 +272,7 @@ void ConfigureGraphics::SetConfiguration() {
     PopulateVSyncModeSelection(); //< must happen after UpdateAPILayout
     SetFSRIndicatorText(ui->fsr_sharpening_slider->sliderPosition());
 
     // V-Sync setting needs to be determined after populating the V-Sync combobox
     if (Settings::IsConfiguringGlobal()) {
         const auto vsync_mode_setting = Settings::values.vsync_mode.GetValue();
         const auto vsync_mode = VSyncSettingToMode(vsync_mode_setting);
@@ -300,13 +300,13 @@ const QString ConfigureGraphics::TranslateVSyncMode(VkPresentModeKHR mode,
     case VK_PRESENT_MODE_IMMEDIATE_KHR:
         return backend == Settings::RendererBackend::OpenGL
                    ? tr("Off")
-                   : QStringLiteral("Immediate (%1)").arg(tr("V-Sync Off"));
+                   : QStringLiteral("Immediate (%1)").arg(tr("VSync Off"));
     case VK_PRESENT_MODE_MAILBOX_KHR:
         return QStringLiteral("Mailbox (%1)").arg(tr("Recommended"));
     case VK_PRESENT_MODE_FIFO_KHR:
         return backend == Settings::RendererBackend::OpenGL
                    ? tr("On")
-                   : QStringLiteral("FIFO (%1)").arg(tr("V-Sync On"));
+                   : QStringLiteral("FIFO (%1)").arg(tr("VSync On"));
     case VK_PRESENT_MODE_FIFO_RELAXED_KHR:
         return QStringLiteral("FIFO Relaxed");
     default:
@@ -272,7 +272,7 @@ void ConfigureGraphics::SetConfiguration() {
     SetFSRIndicatorText(ui->fsr_sharpening_slider->sliderPosition());
 
-    // V-Sync setting needs to be determined after populating the V-Sync combobox
+    // VSync setting needs to be determined after populating the VSync combobox
     if (Settings::IsConfiguringGlobal()) {
         const auto vsync_mode_setting = Settings::values.vsync_mode.GetValue();